@@ -114,7 +114,7 @@ public:
      * @param settings The settings instance of this lxqt panel application.
      * @param parent Parent QWidget, can be omitted.
      */
-    LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidget *parent = 0);
+    LXQtPanel(const QString &configGroup, LXQt::Settings *settings, QWidget *parent = nullptr);
     virtual ~LXQtPanel();
 
     /**
@@ -147,6 +147,7 @@ public:
     QRect calculatePopupWindowPos(const ILXQtPanelPlugin *plugin, const QSize &windowSize) const override;
     void willShowWindow(QWidget * w) override;
     void pluginFlagsChanged(const ILXQtPanelPlugin * plugin) override;
+    bool isLocked() const override { return mLockPanel; }
     // ........ end of ILXQtPanel overrides
 
     /**
