@@ -6,13 +6,13 @@
     <message>
         <location filename="../desktopswitch.cpp" line="85"/>
         <source>Switch to desktop %1</source>
-        <translation type="unfinished">Prebaci na radnu površinu %1</translation>
+        <translation>Prebaci se na radnu površinu %1</translation>
     </message>
     <message>
         <location filename="../desktopswitch.cpp" line="144"/>
         <location filename="../desktopswitch.cpp" line="155"/>
         <source>Desktop %1</source>
-        <translation type="unfinished">Radna površina %1</translation>
+        <translation>Radna površina %1</translation>
     </message>
 </context>
 <context>
@@ -20,52 +20,52 @@
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="14"/>
         <source>DesktopSwitch settings</source>
-        <translation type="unfinished">Postavke prebacivaša radnih površina</translation>
+        <translation>Prebacivanje između radnih površina – Postavke</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="46"/>
         <source>Number of rows:</source>
-        <translation type="unfinished">Broj redaka:</translation>
+        <translation>Broj redaka:</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="39"/>
         <source>Desktop labels:</source>
-        <translation type="unfinished"></translation>
+        <translation>Oznake radnih površina:</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="20"/>
         <source>Appearance</source>
-        <translation type="unfinished"></translation>
+        <translation>Izgled</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="54"/>
         <source>Numbers</source>
-        <translation type="unfinished">Brojevi</translation>
+        <translation>Brojevi</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="59"/>
         <source>Names</source>
-        <translation type="unfinished">Imena</translation>
+        <translation>Imena</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="64"/>
         <source>None</source>
-        <translation type="unfinished"></translation>
+        <translation>Bez</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="72"/>
         <source>If checked, widget will be just an indicator</source>
-        <translation type="unfinished"></translation>
+        <translation>Ako je označeno, programčić će biti samo indikator</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="75"/>
         <source>Show only active desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži samo aktivne radne površine</translation>
     </message>
     <message>
         <location filename="../desktopswitchconfiguration.ui" line="85"/>
         <source>Desktop names</source>
-        <translation type="unfinished"></translation>
+        <translation>Imena radnih površina</translation>
     </message>
 </context>
 </TS>
