@@ -4,48 +4,48 @@
 <context>
     <name>Content</name>
     <message>
-        <location filename="../src/content.cpp" line="43"/>
+        <location filename="../src/content.cpp" line="46"/>
         <source>C</source>
         <comment>Label for CapsLock indicator</comment>
         <translation>C</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="46"/>
+        <location filename="../src/content.cpp" line="49"/>
         <source>CapsLock</source>
         <comment>Tooltip for CapsLock indicator</comment>
         <translation>CapsLock</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="50"/>
+        <location filename="../src/content.cpp" line="53"/>
         <source>N</source>
         <comment>Label for NumLock indicator</comment>
         <translation>N</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="52"/>
+        <location filename="../src/content.cpp" line="55"/>
         <source>NumLock</source>
         <comment>Tooltip for NumLock indicator</comment>
         <translation>NumLock</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="57"/>
+        <location filename="../src/content.cpp" line="60"/>
         <source>S</source>
         <comment>Label for ScrollLock indicator</comment>
         <translation>S</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="59"/>
+        <location filename="../src/content.cpp" line="62"/>
         <source>ScrollLock</source>
         <comment>Tooltip for ScrollLock indicator</comment>
         <translation>ScrollLock</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="90"/>
+        <location filename="../src/content.cpp" line="105"/>
         <source>Layout</source>
         <translation>Kiosztás</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="90"/>
+        <location filename="../src/content.cpp" line="105"/>
         <source>Variant</source>
         <translation>Változat</translation>
     </message>
@@ -65,17 +65,17 @@
     <message>
         <location filename="../src/kbdstateconfig.ui" line="26"/>
         <source>Show Caps Lock</source>
-        <translation>Caps Lock be</translation>
+        <translation>Caps Lock megjelenítése</translation>
     </message>
     <message>
         <location filename="../src/kbdstateconfig.ui" line="33"/>
         <source>Show Num Lock</source>
-        <translation>Num Lock be</translation>
+        <translation>Num Lock megjelenítése</translation>
     </message>
     <message>
         <location filename="../src/kbdstateconfig.ui" line="40"/>
         <source>Show Scroll Lock</source>
-        <translation>Scroll Lock be</translation>
+        <translation type="unfinished">Scroll Lock megjelenítése</translation>
     </message>
     <message>
         <location filename="../src/kbdstateconfig.ui" line="50"/>
@@ -85,12 +85,22 @@
     <message>
         <location filename="../src/kbdstateconfig.ui" line="62"/>
         <source>Switching policy</source>
-        <translation type="unfinished">Szolgáltatásváltás</translation>
+        <translation>Szolgáltatásváltás</translation>
     </message>
     <message>
-        <location filename="../src/kbdstateconfig.ui" line="102"/>
+        <location filename="../src/kbdstateconfig.ui" line="99"/>
+        <source>Flags path pattern:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/kbdstateconfig.ui" line="106"/>
+        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/kbdstateconfig.ui" line="116"/>
         <source>Configure layouts</source>
-        <translation>Kiosztásbeállítás</translation>
+        <translation>Kiosztás beállítása</translation>
     </message>
     <message>
         <location filename="../src/kbdstateconfig.ui" line="69"/>
