@@ -4,48 +4,48 @@
 <context>
     <name>Content</name>
     <message>
-        <location filename="../src/content.cpp" line="43"/>
+        <location filename="../src/content.cpp" line="46"/>
         <source>C</source>
         <comment>Label for CapsLock indicator</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="46"/>
+        <location filename="../src/content.cpp" line="49"/>
         <source>CapsLock</source>
         <comment>Tooltip for CapsLock indicator</comment>
         <translation>大写锁定</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="50"/>
+        <location filename="../src/content.cpp" line="53"/>
         <source>N</source>
         <comment>Label for NumLock indicator</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="52"/>
+        <location filename="../src/content.cpp" line="55"/>
         <source>NumLock</source>
         <comment>Tooltip for NumLock indicator</comment>
         <translation>数字键锁定</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="57"/>
+        <location filename="../src/content.cpp" line="60"/>
         <source>S</source>
         <comment>Label for ScrollLock indicator</comment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="59"/>
+        <location filename="../src/content.cpp" line="62"/>
         <source>ScrollLock</source>
         <comment>Tooltip for ScrollLock indicator</comment>
         <translation>滚动锁定</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="90"/>
+        <location filename="../src/content.cpp" line="105"/>
         <source>Layout</source>
         <translation>布局</translation>
     </message>
     <message>
-        <location filename="../src/content.cpp" line="90"/>
+        <location filename="../src/content.cpp" line="105"/>
         <source>Variant</source>
         <translation>变种</translation>
     </message>
@@ -88,7 +88,17 @@
         <translation>切换策略</translation>
     </message>
     <message>
-        <location filename="../src/kbdstateconfig.ui" line="102"/>
+        <location filename="../src/kbdstateconfig.ui" line="99"/>
+        <source>Flags path pattern:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/kbdstateconfig.ui" line="106"/>
+        <source>File path pattern for country flags. Must contain &lt;strong&gt;%1&lt;/strong&gt; which is replaced by the two letter ISO country code (lower case).&lt;br&gt;&lt;br&gt;Example: /usr/share/iso-flags-svg/country-squared/%1.svg</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/kbdstateconfig.ui" line="116"/>
         <source>Configure layouts</source>
         <translation>配置布局</translation>
     </message>
