@@ -44,10 +44,14 @@
 #include <QApplication>
 
 #include <XdgMenuWidget>
+#include <XdgIcon>
 
 #ifdef HAVE_MENU_CACHE
     #include "xdgcachedmenu.h"
 #else
+    #include <QStandardPaths>
+    #include <QClipboard>
+    #include <QMimeData>
     #include <XdgAction>
 #endif
 
@@ -399,6 +403,7 @@ void LXQtMainMenu::buildMenu()
     mMenu = new XdgCachedMenu(mMenuCache, &mButton);
 #else
     mMenu = new XdgMenuWidget(mXdgMenu, QLatin1String(""), &mButton);
+    addContextMenu(mMenu);
 #endif
     mMenu->setObjectName(QStringLiteral("TopLevelMainMenu"));
     setTranslucentMenus(mMenu);
@@ -435,6 +440,93 @@ void LXQtMainMenu::buildMenu()
     setMenuFontSize();
 }
 
+/************************************************
+
+ ************************************************/
+void LXQtMainMenu::addContextMenu(QMenu *menu)
+{
+    const auto actions = menu->actions();
+    for (auto const & action : actions)
+    {
+        if (action->menu())
+        {
+            action->menu()->setContextMenuPolicy(Qt::CustomContextMenu);
+            connect(action->menu(), &QWidget::customContextMenuRequested,
+                    this, &LXQtMainMenu::onRequestingCustomMenu);
+            addContextMenu(action->menu());
+        }
+    }
+}
+
+void LXQtMainMenu::onRequestingCustomMenu(const QPoint& p)
+{
+#ifdef HAVE_MENU_CACHE
+    Q_UNUSED(p)
+    return;
+#else
+    QMenu *parentMenu = static_cast<QMenu*>(QObject::sender());
+    if (parentMenu == nullptr)
+        return;
+    QAction *action = parentMenu->actionAt(p);
+    if (action == nullptr || action->menu() != nullptr || action->isSeparator())
+        return;
+    XdgAction *xdgAction = qobject_cast<XdgAction *>(action);
+    if (xdgAction == nullptr)
+        return;
+    const XdgDesktopFile& df = xdgAction->desktopFile();
+    QString file = df.fileName();
+
+    QMenu menu;
+    QAction *a;
+
+    if (df.actions().count() > 0 && df.type() == XdgDesktopFile::Type::ApplicationType)
+    {
+        for (int i = 0; i < df.actions().count(); ++i)
+        {
+            QString action(df.actions().at(i));
+            a = menu.addAction(df.actionIcon(action), df.actionName(action));
+            connect(a, &QAction::triggered, [this, df, action] {
+                df.actionActivate(action, QStringList());
+                mMenu->hide();
+            });
+        }
+        menu.addSeparator();
+    }
+
+    a = menu.addAction(XdgIcon::fromTheme(QLatin1String("desktop")), tr("Add to desktop"));
+    connect(a, &QAction::triggered, [file] {
+        QString desktop = QStandardPaths::writableLocation(QStandardPaths::DesktopLocation);
+        QString desktopFile = desktop + QStringLiteral("/") + file.section(QStringLiteral("/"), -1);
+        if (QFile::exists(desktopFile))
+        {
+            QMessageBox::StandardButton btn =
+            QMessageBox::question(nullptr,
+                                  tr("Question"),
+                                  tr("A file with the same name already exists.\nDo you want to overwrite it?"));
+            if (btn == QMessageBox::No)
+                return;
+            if (!QFile::remove(desktopFile))
+            {
+                QMessageBox::warning(nullptr,
+                                     tr("Warning"),
+                                     tr("The file cannot be overwritten."));
+                return;
+            }
+        }
+        QFile::copy(file, desktopFile);
+    });
+    a = menu.addAction(XdgIcon::fromTheme(QLatin1String("edit-copy")), tr("Copy"));
+    connect(a, &QAction::triggered, [file] {
+        QClipboard* clipboard = QApplication::clipboard();
+        QMimeData* data = new QMimeData();
+        data->setData(QStringLiteral("text/uri-list"), QUrl::fromLocalFile(file).toEncoded()
+                                                       + QByteArray("\r\n"));
+        clipboard->setMimeData(data);
+    });
+    menu.exec(parentMenu->mapToGlobal(p));
+#endif
+}
+
 /************************************************
 
  ************************************************/
@@ -543,7 +635,7 @@ bool LXQtMainMenu::eventFilter(QObject *obj, QEvent *event)
                 QAction* action = menu->activeAction();
                 if(action !=0) {
                     QList<QAction*> actions = menu->actions();
-                    QList<QAction*>::iterator it = qFind(actions.begin(), actions.end(), action);
+                    QList<QAction*>::iterator it = std::find(actions.begin(), actions.end(), action);
                     it = std::find_if(it + 1, actions.end(), MatchAction(key));
                     if(it == actions.end())
                         it = std::find_if(actions.begin(), it, MatchAction(key));
