@@ -52,14 +52,14 @@ MenuDiskItem::MenuDiskItem(Solid::Device device, Popup *popup):
     Q_ASSERT(nullptr != iface);
 
     mDiskButton = new QToolButton(this);
-    mDiskButton->setObjectName("DiskButton");
+    mDiskButton->setObjectName(QStringLiteral("DiskButton"));
     mDiskButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mDiskButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
     connect(mDiskButton, &QToolButton::clicked, this, &MenuDiskItem::diskButtonClicked);
 
     mEjectButton = new QToolButton(this);
-    mEjectButton->setObjectName("EjectButton");
-    mEjectButton->setIcon(XdgIcon::fromTheme("media-eject"));
+    mEjectButton->setObjectName(QStringLiteral("EjectButton"));
+    mEjectButton->setIcon(XdgIcon::fromTheme(QStringLiteral("media-eject")));
     connect(mEjectButton, &QToolButton::clicked, this, &MenuDiskItem::ejectButtonClicked);
 
     QHBoxLayout *layout = new QHBoxLayout(this);
@@ -71,7 +71,7 @@ MenuDiskItem::MenuDiskItem(Solid::Device device, Popup *popup):
 
     connect(iface, &Solid::StorageAccess::setupDone, this, &MenuDiskItem::onMounted);
     connect(iface, &Solid::StorageAccess::teardownDone, this, &MenuDiskItem::onUnmounted);
-    connect(iface, &Solid::StorageAccess::accessibilityChanged, [this] (bool accessible, QString const &) {
+    connect(iface, &Solid::StorageAccess::accessibilityChanged, [this] (bool /*accessible*/, QString const &) {
         updateMountStatus();
     });
 
@@ -142,7 +142,7 @@ void MenuDiskItem::ejectButtonClicked()
     mPopup->hide();
 }
 
-void MenuDiskItem::onMounted(Solid::ErrorType error, QVariant resultData, const QString &udi)
+void MenuDiskItem::onMounted(Solid::ErrorType error, QVariant resultData, const QString & /*udi*/)
 {
     if (mDiskButtonClicked)
     {
@@ -159,7 +159,7 @@ void MenuDiskItem::onMounted(Solid::ErrorType error, QVariant resultData, const
     }
 }
 
-void MenuDiskItem::onUnmounted(Solid::ErrorType error, QVariant resultData, const QString &udi)
+void MenuDiskItem::onUnmounted(Solid::ErrorType error, QVariant resultData, const QString & /*udi*/)
 {
     if (mEjectButtonClicked)
     {
