@@ -22,25 +22,41 @@
         <translation>Comportamiento</translation>
     </message>
     <message>
-        <location filename="../configuration.ui" line="26"/>
+        <location filename="../configuration.ui" line="32"/>
         <source>When a device is connected:</source>
         <translation>Al conectar un dispositivo:</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="40"/>
+        <location filename="../configuration.ui" line="42"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuration.ui" line="45"/>
+        <source>When eject button is pressed:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../configuration.cpp" line="43"/>
         <source>Popup menu</source>
         <translation>Menú contextual</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="41"/>
+        <location filename="../configuration.cpp" line="44"/>
         <source>Show info</source>
         <translation>Mostrar información</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="42"/>
+        <location filename="../configuration.cpp" line="45"/>
+        <location filename="../configuration.cpp" line="50"/>
         <source>Do nothing</source>
         <translation>No hacer nada</translation>
     </message>
+    <message>
+        <location filename="../configuration.cpp" line="51"/>
+        <source>Eject All Optical Drives</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DeviceActionInfo</name>
@@ -60,6 +76,32 @@
         <translation>Gestor de medios y dispositivos extraíbles</translation>
     </message>
 </context>
+<context>
+    <name>EjectActionOptical</name>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Removable media/devices manager</source>
+        <translation type="unfinished">Gestor de medios y dispositivos extraíbles</translation>
+    </message>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Ejected all optical drives</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LXQtMountPlugin</name>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="79"/>
+        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="116"/>
+        <source>Eject removable media</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MenuDiskItem</name>
     <message>
