@@ -22,25 +22,41 @@
         <translation>Comportamento</translation>
     </message>
     <message>
-        <location filename="../configuration.ui" line="26"/>
+        <location filename="../configuration.ui" line="32"/>
         <source>When a device is connected:</source>
         <translation>Quando un device è connesso:</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="40"/>
+        <location filename="../configuration.ui" line="42"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esegui sempre la seguente azione alla pressione del pulsante di espulsione (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../configuration.ui" line="45"/>
+        <source>When eject button is pressed:</source>
+        <translation>Se pressato pulsante di espulsione:</translation>
+    </message>
+    <message>
+        <location filename="../configuration.cpp" line="43"/>
         <source>Popup menu</source>
         <translation>Menu a comparsa</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="41"/>
+        <location filename="../configuration.cpp" line="44"/>
         <source>Show info</source>
         <translation>Mostra informazioni</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="42"/>
+        <location filename="../configuration.cpp" line="45"/>
+        <location filename="../configuration.cpp" line="50"/>
         <source>Do nothing</source>
         <translation>Non fare nulla</translation>
     </message>
+    <message>
+        <location filename="../configuration.cpp" line="51"/>
+        <source>Eject All Optical Drives</source>
+        <translation>Espelli tutti dispositivi ottici</translation>
+    </message>
 </context>
 <context>
     <name>DeviceActionInfo</name>
@@ -60,6 +76,32 @@
         <translation>Gestore dei supporti/dispositivi rimovibili</translation>
     </message>
 </context>
+<context>
+    <name>EjectActionOptical</name>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Removable media/devices manager</source>
+        <translation type="unfinished">Gestore dei supporti/dispositivi rimovibili</translation>
+    </message>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Ejected all optical drives</source>
+        <translation>Espelli tutti dischi ottici</translation>
+    </message>
+</context>
+<context>
+    <name>LXQtMountPlugin</name>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="79"/>
+        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
+        <translation>Gestore dispositivi rimovibili: Impossibile registrare scorciatoia globale &apos;%1&apos;</translation>
+    </message>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="116"/>
+        <source>Eject removable media</source>
+        <translation>Espelli dispositivo rimovibile</translation>
+    </message>
+</context>
 <context>
     <name>MenuDiskItem</name>
     <message>
