@@ -22,25 +22,41 @@
         <translation>動作</translation>
     </message>
     <message>
-        <location filename="../configuration.ui" line="26"/>
+        <location filename="../configuration.ui" line="32"/>
         <source>When a device is connected:</source>
         <translation>デバイスが接続された時:</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="40"/>
+        <location filename="../configuration.ui" line="42"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;取り出しのショートカットが押されると次のアクションが起こります(既定では &lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; )&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../configuration.ui" line="45"/>
+        <source>When eject button is pressed:</source>
+        <translation>取り出しボタンが押された時:</translation>
+    </message>
+    <message>
+        <location filename="../configuration.cpp" line="43"/>
         <source>Popup menu</source>
         <translation>メニューのポップアップ</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="41"/>
+        <location filename="../configuration.cpp" line="44"/>
         <source>Show info</source>
         <translation>情報の表示</translation>
     </message>
     <message>
-        <location filename="../configuration.cpp" line="42"/>
+        <location filename="../configuration.cpp" line="45"/>
+        <location filename="../configuration.cpp" line="50"/>
         <source>Do nothing</source>
         <translation>何もしない</translation>
     </message>
+    <message>
+        <location filename="../configuration.cpp" line="51"/>
+        <source>Eject All Optical Drives</source>
+        <translation>すべての光学式ドライブを取り出す</translation>
+    </message>
 </context>
 <context>
     <name>DeviceActionInfo</name>
@@ -60,6 +76,32 @@
         <translation>リムーバブルメディア/デバイスの管理</translation>
     </message>
 </context>
+<context>
+    <name>EjectActionOptical</name>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Removable media/devices manager</source>
+        <translation>リムーバブルメディアとデバイスの管理</translation>
+    </message>
+    <message>
+        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
+        <source>Ejected all optical drives</source>
+        <translation>すべての光学式ドライブを取り出しました</translation>
+    </message>
+</context>
+<context>
+    <name>LXQtMountPlugin</name>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="79"/>
+        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
+        <translation>リムーバブルメディア/デバイスのマネージャー: グローバルショートカット &apos;%1&apos; を登録できません</translation>
+    </message>
+    <message>
+        <location filename="../lxqtmountplugin.cpp" line="116"/>
+        <source>Eject removable media</source>
+        <translation>リムーバブルメディアを取り出す</translation>
+    </message>
+</context>
 <context>
     <name>MenuDiskItem</name>
     <message>
