@@ -17,7 +17,7 @@
         <location filename="../lxqtquicklaunch.cpp" line="333"/>
         <source>Drop application
 icons here</source>
-        <translation>Ejts ide
+        <translation>Rakjon ide
 indító ikonokat</translation>
     </message>
 </context>
@@ -25,16 +25,21 @@ indító ikonokat</translation>
     <name>QuickLaunchButton</name>
     <message>
         <location filename="../quicklaunchbutton.cpp" line="55"/>
+        <source>(Ctrl + DND)</source>
+        <translation>(Ctrl + húzás)</translation>
+    </message>
+    <message>
+        <location filename="../quicklaunchbutton.cpp" line="57"/>
         <source>Move left</source>
         <translation>Balra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="58"/>
+        <location filename="../quicklaunchbutton.cpp" line="60"/>
         <source>Move right</source>
         <translation>Jobbra</translation>
     </message>
     <message>
-        <location filename="../quicklaunchbutton.cpp" line="62"/>
+        <location filename="../quicklaunchbutton.cpp" line="64"/>
         <source>Remove from quicklaunch</source>
         <translation>Eltávolítás a gyorsindítóról</translation>
     </message>
