@@ -4,17 +4,17 @@
 <context>
     <name>ShowDesktop</name>
     <message>
-        <location filename="../showdesktop.cpp" line="48"/>
+        <location filename="../showdesktop.cpp" line="44"/>
         <source>Show desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Rodyti darbalaukį</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="58"/>
+        <location filename="../showdesktop.cpp" line="66"/>
         <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
-        <translation>Rodyti darbalaukį: globalusis klavišas „%1“ negali būti registruojamas</translation>
+        <translation>Rodyti darbalaukį: Visuotinis spartusis klavišas &quot;%1&quot; negali būti užregistruotas</translation>
     </message>
     <message>
-        <location filename="../showdesktop.cpp" line="63"/>
+        <location filename="../showdesktop.cpp" line="51"/>
         <source>Show Desktop</source>
         <translation>Rodyti darbalaukį</translation>
     </message>
