@@ -30,6 +30,7 @@
 #define STATUSNOTIFIERWIDGET_H
 
 #include <QDir>
+#include <QTimer>
 
 #include <LXQt/GridLayout>
 
@@ -44,6 +45,9 @@ public:
     StatusNotifierWidget(ILXQtPanelPlugin *plugin, QWidget *parent = nullptr);
     ~StatusNotifierWidget();
 
+    void settingsChanged();
+    QStringList itemTitles() const;
+
 signals:
 
 public slots:
@@ -52,11 +56,24 @@ public slots:
 
     void realign();
 
+protected:
+    void leaveEvent(QEvent *event) override;
+    void enterEvent(QEvent *event) override;
+
 private:
     ILXQtPanelPlugin *mPlugin;
     StatusNotifierWatcher *mWatcher;
 
+    QTimer mHideTimer;
+
     QHash<QString, StatusNotifierButton*> mServices;
+
+    QStringList mItemTitles;
+    QStringList mAutoHideList;
+    QStringList mHideList;
+    QToolButton *mShowBtn;
+    int mAttentionPeriod;
+    bool mForceVisible;
 };
 
 #endif // STATUSNOTIFIERWIDGET_H
