@@ -41,29 +41,29 @@ LXQtSysStatColours::LXQtSysStatColours(QWidget *parent) :
     setWindowModality(Qt::WindowModal);
     ui->setupUi(this);
 
-    mDefaultColours["grid"]  = QColor("#808080");
-    mDefaultColours["title"] = QColor("#000000");
+    mDefaultColours[QStringLiteral("grid")]  = QColor("#808080");
+    mDefaultColours[QStringLiteral("title")] = QColor("#000000");
 
-    mDefaultColours["cpuSystem"]    = QColor("#800000");
-    mDefaultColours["cpuUser"]      = QColor("#000080");
-    mDefaultColours["cpuNice"]      = QColor("#008000");
-    mDefaultColours["cpuOther"]     = QColor("#808000");
-    mDefaultColours["cpuFrequency"] = QColor("#808080");
+    mDefaultColours[QStringLiteral("cpuSystem")]    = QColor("#800000");
+    mDefaultColours[QStringLiteral("cpuUser")]      = QColor("#000080");
+    mDefaultColours[QStringLiteral("cpuNice")]      = QColor("#008000");
+    mDefaultColours[QStringLiteral("cpuOther")]     = QColor("#808000");
+    mDefaultColours[QStringLiteral("cpuFrequency")] = QColor("#808080");
 
-    mDefaultColours["memApps"]    = QColor("#000080");
-    mDefaultColours["memBuffers"] = QColor("#008000");
-    mDefaultColours["memCached"]  = QColor("#808000");
-    mDefaultColours["memSwap"]    = QColor("#800000");
+    mDefaultColours[QStringLiteral("memApps")]    = QColor("#000080");
+    mDefaultColours[QStringLiteral("memBuffers")] = QColor("#008000");
+    mDefaultColours[QStringLiteral("memCached")]  = QColor("#808000");
+    mDefaultColours[QStringLiteral("memSwap")]    = QColor("#800000");
 
-    mDefaultColours["netReceived"]    = QColor("#000080");
-    mDefaultColours["netTransmitted"] = QColor("#808000");
+    mDefaultColours[QStringLiteral("netReceived")]    = QColor("#000080");
+    mDefaultColours[QStringLiteral("netTransmitted")] = QColor("#808000");
 
 
 #undef CONNECT_SELECT_COLOUR
 #define CONNECT_SELECT_COLOUR(VAR) \
     connect(ui-> VAR ## B, SIGNAL(clicked()), mSelectColourMapper, SLOT(map())); \
-    mSelectColourMapper->setMapping(ui-> VAR ## B, QString( #VAR )); \
-    mShowColourMap[QString( #VAR )] = ui-> VAR ## B;
+    mSelectColourMapper->setMapping(ui-> VAR ## B, QString::fromLatin1( #VAR )); \
+    mShowColourMap[QString::fromLatin1( #VAR )] = ui-> VAR ## B;
 
     CONNECT_SELECT_COLOUR(grid)
     CONNECT_SELECT_COLOUR(title)
@@ -95,7 +95,7 @@ void LXQtSysStatColours::selectColour(const QString &name)
     if (color.isValid())
     {
         mColours[name] = color;
-        mShowColourMap[name]->setStyleSheet(QString("background-color: %1;\ncolor: %2;").arg(color.name()).arg((color.toHsl().lightnessF() > 0.5) ? "black" : "white"));
+        mShowColourMap[name]->setStyleSheet(QStringLiteral("background-color: %1;\ncolor: %2;").arg(color.name()).arg((color.toHsl().lightnessF() > 0.5) ? QStringLiteral("black") : QStringLiteral("white")));
 
         ui->buttons->button(QDialogButtonBox::Apply)->setEnabled(true);
     }
@@ -116,7 +116,7 @@ void LXQtSysStatColours::applyColoursToButtons()
     for (Colours::ConstIterator I = mColours.constBegin(); I != M; ++I)
     {
         const QColor &color = I.value();
-        mShowColourMap[I.key()]->setStyleSheet(QString("background-color: %1;\ncolor: %2;").arg(color.name()).arg((color.toHsl().lightnessF() > 0.5) ? "black" : "white"));
+        mShowColourMap[I.key()]->setStyleSheet(QStringLiteral("background-color: %1;\ncolor: %2;").arg(color.name()).arg((color.toHsl().lightnessF() > 0.5) ? QStringLiteral("black") : QStringLiteral("white")));
     }
 }
 
