@@ -118,6 +118,11 @@
         <source>Graph</source>
         <translation>Gráfico</translation>
     </message>
+    <message>
+        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height if the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Largura mínima do painel se na horizontal.&lt;/p&gt;&lt;p&gt;Altura mínima do painel se na vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
     <message>
         <location filename="../lxqtsysstatconfiguration.ui" line="83"/>
         <source> px</source>
@@ -158,11 +163,6 @@
         <source>&amp;Grid lines</source>
         <translation>Linhas da &amp;grelha</translation>
     </message>
-    <message>
-        <location filename="../lxqtsysstatconfiguration.ui" line="80"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Minimal width if the panel is horizontal.&lt;/p&gt;&lt;p&gt;Minimal height is the panel is vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Largura mínima se o painel for horizontal.&lt;/p&gt;&lt;p&gt;Altura mínima se o painel for vertical.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
     <message>
         <location filename="../lxqtsysstatconfiguration.ui" line="149"/>
         <source>Use &amp;frequency</source>
