@@ -4,107 +4,117 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../lxqttaskbar.cpp" line="650"/>
+        <location filename="../lxqttaskbar.cpp" line="681"/>
         <source>Activate task %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktiviraj zadatak %1</translation>
     </message>
 </context>
 <context>
     <name>LXQtTaskButton</name>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="576"/>
-        <source>Application</source>
-        <translation type="unfinished">Program</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="610"/>
-        <source>To &amp;Desktop</source>
-        <translation type="unfinished">Na &amp;radnu površinu</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="612"/>
-        <source>&amp;All Desktops</source>
-        <translation type="unfinished">&amp;Sve radne površine</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="620"/>
-        <source>Desktop &amp;%1</source>
-        <translation type="unfinished">Radna površina &amp;%1</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="627"/>
-        <source>&amp;To Current Desktop</source>
-        <translation type="unfinished">&amp;Na trenutnu radnu površinu</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="635"/>
-        <source>&amp;Move</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="638"/>
-        <source>Resi&amp;ze</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="645"/>
-        <source>Ma&amp;ximize</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="652"/>
-        <source>Maximize vertically</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="657"/>
-        <source>Maximize horizontally</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="663"/>
-        <source>&amp;Restore</source>
-        <translation type="unfinished">&amp;Obnovi</translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="667"/>
-        <source>Mi&amp;nimize</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbutton.cpp" line="673"/>
-        <source>Roll down</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../lxqttaskbutton.cpp" line="679"/>
+        <source>Application</source>
+        <translation>Program</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="713"/>
+        <source>To &amp;Desktop</source>
+        <translation>Na &amp;radnu površinu</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="715"/>
+        <source>&amp;All Desktops</source>
+        <translation>&amp;Sve radne površine</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="723"/>
+        <source>Desktop &amp;%1</source>
+        <translation>Radna površina &amp;%1</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="730"/>
+        <source>&amp;To Current Desktop</source>
+        <translation>Na &amp;trenutačnu radnu površinu</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="739"/>
+        <source>Move To &amp;Next Monitor</source>
+        <translation>Premjesti na &amp;sljedeći monitor</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="742"/>
+        <source>Move To &amp;Previous Monitor</source>
+        <translation>Premjesti na &amp;prethodni monitor</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="746"/>
+        <source>&amp;Move</source>
+        <translation>Pre&amp;mjesti</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="749"/>
+        <source>Resi&amp;ze</source>
+        <translation>Promijeni &amp;veličinu</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="756"/>
+        <source>Ma&amp;ximize</source>
+        <translation>Ma&amp;ksimiraj</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="763"/>
+        <source>Maximize vertically</source>
+        <translation>Maksimiraj okomito</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="768"/>
+        <source>Maximize horizontally</source>
+        <translation>Maksimiraj vodoravno</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="774"/>
+        <source>&amp;Restore</source>
+        <translation>&amp;Obnovi</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="778"/>
+        <source>Mi&amp;nimize</source>
+        <translation>Mi&amp;nimiraj</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="784"/>
+        <source>Roll down</source>
+        <translation>Rasklopi naslovnu traku</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="790"/>
         <source>Roll up</source>
-        <translation type="unfinished"></translation>
+        <translation>Sklopi u naslovnu traku</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="687"/>
+        <location filename="../lxqttaskbutton.cpp" line="798"/>
         <source>&amp;Layer</source>
-        <translation type="unfinished"></translation>
+        <translation>S&amp;loj</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="689"/>
+        <location filename="../lxqttaskbutton.cpp" line="800"/>
         <source>Always on &amp;top</source>
-        <translation type="unfinished">Uvijek na &amp;vrhu</translation>
+        <translation>Uvijek izna&amp;d</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="695"/>
+        <location filename="../lxqttaskbutton.cpp" line="806"/>
         <source>&amp;Normal</source>
-        <translation type="unfinished">&amp;Normalno</translation>
+        <translation>&amp;Normalno</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="701"/>
+        <location filename="../lxqttaskbutton.cpp" line="812"/>
         <source>Always on &amp;bottom</source>
-        <translation type="unfinished">Uvijek na &amp;dnu</translation>
+        <translation>Uvijek i&amp;spod</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="709"/>
+        <location filename="../lxqttaskbutton.cpp" line="820"/>
         <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Zatvori</translation>
+        <translation>&amp;Zatvori</translation>
     </message>
 </context>
 <context>
@@ -112,12 +122,12 @@
     <message>
         <location filename="../lxqttaskgroup.cpp" line="82"/>
         <source>Group</source>
-        <translation type="unfinished">Grupa</translation>
+        <translation>Grupa</translation>
     </message>
     <message>
         <location filename="../lxqttaskgroup.cpp" line="84"/>
         <source>Close group</source>
-        <translation type="unfinished">Zatvori grupu</translation>
+        <translation>Zatvori grupu</translation>
     </message>
 </context>
 <context>
@@ -125,134 +135,149 @@
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
         <source>Task Manager Settings</source>
-        <translation type="unfinished">Postavke upravitelja zadacima</translation>
+        <translation>Upravljač zadataka – Postavke</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
         <source>General</source>
-        <translation type="unfinished">Općenito</translation>
+        <translation>Opće</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
         <source>Show only windows from desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži samo prozore s radne površine</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
         <source>Show only windows from &amp;panel&apos;s screen</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži samo prozore s ekrana ploče</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
         <source>Show only minimized windows</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži samo smanjene prozore</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
         <source>Raise minimized windows on current desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Nadigni smanjene prozore na trenutačnoj radnoj površini</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
         <source>Close on middle-click</source>
-        <translation type="unfinished"></translation>
+        <translation>Zatvori pritiskom srednje gumba</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
         <source>Cycle windows on wheel scrolling</source>
-        <translation type="unfinished"></translation>
+        <translation>Prelazi po prozorima okretanjem kotačića miša</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
         <source>Window &amp;grouping</source>
-        <translation type="unfinished">Grupiranje prozora</translation>
+        <translation>&amp;Grupiranje prozora</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
         <source>Show popup on mouse hover</source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži skočni prozor prilikom prelaska mišem</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
         <source>Appearance</source>
-        <translation type="unfinished">Izgled</translation>
+        <translation>Izgled</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
         <source>Button style</source>
-        <translation type="unfinished"></translation>
+        <translation>Stil gumba</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
         <source>Maximum button width</source>
-        <translation type="unfinished"></translation>
+        <translation>Maksimalna širina gumba</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
         <source> px</source>
-        <translation type="unfinished"> px</translation>
+        <translation> px</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
         <source>Mouse Wheel</source>
-        <translation type="unfinished"></translation>
+        <translation>Kotačić miša</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
         <source>Wheel Delta Threshold</source>
-        <translation type="unfinished"></translation>
+        <translation>Prag razlike kotačića</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <source>Put buttons of the same class next to each other</source>
+        <translation>Stavi gumbe iste klase jedan pored drugog</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
         <source>Maximum button height</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
-        <source>Auto&amp;rotate buttons when the panel is vertical</source>
-        <translation type="unfinished"></translation>
+        <translation>Maksimalna visina gumba</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
+        <source>Auto&amp;rotate buttons when the panel is vertical</source>
+        <translation>Automatski ok&amp;reni gumbe kad ploča stoji okomito</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
         <source>Use icons by WindowClass, if available</source>
-        <translation type="unfinished"></translation>
+        <translation>Koristi ikone na osnovi WindowClass, ako je dostupno</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
         <source>Icon and text</source>
-        <translation type="unfinished">Ikona i tekst</translation>
+        <translation>Ikona i tekst</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
         <source>Only icon</source>
-        <translation type="unfinished">Samo ikona</translation>
+        <translation>Samo ikone</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
         <source>Only text</source>
-        <translation type="unfinished">Samo tekst</translation>
+        <translation>Samo tekst</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
         <source>Disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Deaktivirano</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
         <source>Scroll up to raise, down to minimize</source>
-        <translation type="unfinished"></translation>
+        <translation>Kliži gore za nadizanje, dolje za smanjivanje</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
         <source>Scroll up to minimize, down to raise</source>
-        <translation type="unfinished"></translation>
+        <translation>Kliži gore za smanjivanje, dolje za nadizanje</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
+        <source>Scroll up to move to next desktop, down to previous</source>
+        <translation>Kliži gore za prelaženje na sljedeću radnu površinu, dolje na prethodnu</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
+        <source>Scroll up to move to previous desktop, down to next</source>
+        <translation>Kliži gore za prelaženje na prethodnu radnu površinu, dolje na sljedeću</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
         <source>Current</source>
-        <translation type="unfinished"></translation>
+        <translation>Trenutačna</translation>
     </message>
 </context>
 </TS>
