@@ -4,7 +4,7 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../lxqttaskbar.cpp" line="650"/>
+        <location filename="../lxqttaskbar.cpp" line="681"/>
         <source>Activate task %1</source>
         <translation>アクティブなタスク %1</translation>
     </message>
@@ -12,97 +12,107 @@
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="576"/>
+        <location filename="../lxqttaskbutton.cpp" line="679"/>
         <source>Application</source>
         <translation>アプリケーション</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="610"/>
+        <location filename="../lxqttaskbutton.cpp" line="713"/>
         <source>To &amp;Desktop</source>
         <translation>デスクトップへ(&amp;D)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="612"/>
+        <location filename="../lxqttaskbutton.cpp" line="715"/>
         <source>&amp;All Desktops</source>
         <translation>すべてのデスクトップ(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="620"/>
+        <location filename="../lxqttaskbutton.cpp" line="723"/>
         <source>Desktop &amp;%1</source>
         <translation>デスクトップ &amp;%1</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="627"/>
+        <location filename="../lxqttaskbutton.cpp" line="730"/>
         <source>&amp;To Current Desktop</source>
-        <translation>現在のデスクトップへ(&amp;T)</translation>
+        <translation>現在のデスクトップに(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="635"/>
+        <location filename="../lxqttaskbutton.cpp" line="739"/>
+        <source>Move To &amp;Next Monitor</source>
+        <translation>次のモニターへ移動(&amp;N)</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="742"/>
+        <source>Move To &amp;Previous Monitor</source>
+        <translation>前のモニターへ移動(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="746"/>
         <source>&amp;Move</source>
         <translation>移動(&amp;M)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="638"/>
+        <location filename="../lxqttaskbutton.cpp" line="749"/>
         <source>Resi&amp;ze</source>
         <translation>サイズの変更(&amp;Z)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="645"/>
+        <location filename="../lxqttaskbutton.cpp" line="756"/>
         <source>Ma&amp;ximize</source>
         <translation>最大化(&amp;X)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="652"/>
+        <location filename="../lxqttaskbutton.cpp" line="763"/>
         <source>Maximize vertically</source>
         <translation>縦方向の最大化</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="657"/>
+        <location filename="../lxqttaskbutton.cpp" line="768"/>
         <source>Maximize horizontally</source>
         <translation>横方向の最大化</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="663"/>
+        <location filename="../lxqttaskbutton.cpp" line="774"/>
         <source>&amp;Restore</source>
         <translation>復元(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="667"/>
+        <location filename="../lxqttaskbutton.cpp" line="778"/>
         <source>Mi&amp;nimize</source>
         <translation>最小化(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="673"/>
+        <location filename="../lxqttaskbutton.cpp" line="784"/>
         <source>Roll down</source>
         <translation>広げる</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="679"/>
+        <location filename="../lxqttaskbutton.cpp" line="790"/>
         <source>Roll up</source>
         <translation>たたむ</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="687"/>
+        <location filename="../lxqttaskbutton.cpp" line="798"/>
         <source>&amp;Layer</source>
         <translation>レイヤー(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="689"/>
+        <location filename="../lxqttaskbutton.cpp" line="800"/>
         <source>Always on &amp;top</source>
         <translation>常に手前に表示(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="695"/>
+        <location filename="../lxqttaskbutton.cpp" line="806"/>
         <source>&amp;Normal</source>
         <translation>通常(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="701"/>
+        <location filename="../lxqttaskbutton.cpp" line="812"/>
         <source>Always on &amp;bottom</source>
         <translation>常に奥に表示(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="709"/>
+        <location filename="../lxqttaskbutton.cpp" line="820"/>
         <source>&amp;Close</source>
         <translation>閉じる(&amp;C)</translation>
     </message>
@@ -128,12 +138,12 @@
         <translation>タスク管理の設定</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
         <source>Auto&amp;rotate buttons when the panel is vertical</source>
         <translation>パネルが垂直なときにはボタンを回転させる(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
         <source>Button style</source>
         <translation>ボタンのスタイル</translation>
     </message>
@@ -183,19 +193,19 @@
         <translation>マウスを合わせるとポップアップでタイトルを表示する</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
         <source>Appearance</source>
         <translation>外観</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
         <source>Maximum button width</source>
         <translation>ボタンの最大幅</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
         <source> px</source>
         <translation> ピクセル</translation>
     </message>
@@ -210,12 +220,17 @@
         <translation>ホイールの変化量のしきい値</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <source>Put buttons of the same class next to each other</source>
+        <translation>同じクラスのボタンを隣同士に置く</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
         <source>Maximum button height</source>
         <translation>ボタンの最大高</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
         <source>Use icons by WindowClass, if available</source>
         <translation>可能であれば WindowClass のアイコンを使用する</translation>
     </message>
@@ -249,8 +264,18 @@
         <source>Scroll up to minimize, down to raise</source>
         <translation>スクロールアップで最小化、スクロールダウンで最前面</translation>
     </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
+        <source>Scroll up to move to next desktop, down to previous</source>
+        <translation>スクロールアップで次のデスクトップへ移動、ダウンで前のデスクトップへ</translation>
+    </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
+        <source>Scroll up to move to previous desktop, down to next</source>
+        <translation>スクロールアップで前のデスクトップへ移動、ダウンで次のデスクトップへ</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
         <source>Current</source>
         <translation>現在のデスクトップ</translation>
     </message>
