@@ -4,7 +4,7 @@
 <context>
     <name>LXQtTaskBar</name>
     <message>
-        <location filename="../lxqttaskbar.cpp" line="650"/>
+        <location filename="../lxqttaskbar.cpp" line="681"/>
         <source>Activate task %1</source>
         <translation>작업 %1 실행</translation>
     </message>
@@ -12,97 +12,107 @@
 <context>
     <name>LXQtTaskButton</name>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="576"/>
+        <location filename="../lxqttaskbutton.cpp" line="679"/>
         <source>Application</source>
         <translation>애플리케이션</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="610"/>
+        <location filename="../lxqttaskbutton.cpp" line="713"/>
         <source>To &amp;Desktop</source>
         <translation>바탕화면으로(&amp;D)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="612"/>
+        <location filename="../lxqttaskbutton.cpp" line="715"/>
         <source>&amp;All Desktops</source>
         <translation>모든 바탕화면(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="620"/>
+        <location filename="../lxqttaskbutton.cpp" line="723"/>
         <source>Desktop &amp;%1</source>
         <translation>바탕화면 &amp;%1</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="627"/>
+        <location filename="../lxqttaskbutton.cpp" line="730"/>
         <source>&amp;To Current Desktop</source>
         <translation>현재 바탕화면으로(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="635"/>
+        <location filename="../lxqttaskbutton.cpp" line="739"/>
+        <source>Move To &amp;Next Monitor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="742"/>
+        <source>Move To &amp;Previous Monitor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbutton.cpp" line="746"/>
         <source>&amp;Move</source>
         <translation>이동(&amp;M)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="638"/>
+        <location filename="../lxqttaskbutton.cpp" line="749"/>
         <source>Resi&amp;ze</source>
         <translation>크기 조절(&amp;Z)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="645"/>
+        <location filename="../lxqttaskbutton.cpp" line="756"/>
         <source>Ma&amp;ximize</source>
         <translation>최대화(&amp;X)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="652"/>
+        <location filename="../lxqttaskbutton.cpp" line="763"/>
         <source>Maximize vertically</source>
         <translation>세로로 최대화</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="657"/>
+        <location filename="../lxqttaskbutton.cpp" line="768"/>
         <source>Maximize horizontally</source>
         <translation>가로로 최대화</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="663"/>
+        <location filename="../lxqttaskbutton.cpp" line="774"/>
         <source>&amp;Restore</source>
         <translation>복원(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="667"/>
+        <location filename="../lxqttaskbutton.cpp" line="778"/>
         <source>Mi&amp;nimize</source>
         <translation>최소화(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="673"/>
+        <location filename="../lxqttaskbutton.cpp" line="784"/>
         <source>Roll down</source>
         <translation>아래로 내리기</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="679"/>
+        <location filename="../lxqttaskbutton.cpp" line="790"/>
         <source>Roll up</source>
         <translation>위로 올리기</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="687"/>
+        <location filename="../lxqttaskbutton.cpp" line="798"/>
         <source>&amp;Layer</source>
         <translation>레이어(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="689"/>
+        <location filename="../lxqttaskbutton.cpp" line="800"/>
         <source>Always on &amp;top</source>
         <translation>항상 위에(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="695"/>
+        <location filename="../lxqttaskbutton.cpp" line="806"/>
         <source>&amp;Normal</source>
         <translation>기본(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="701"/>
+        <location filename="../lxqttaskbutton.cpp" line="812"/>
         <source>Always on &amp;bottom</source>
         <translation>항상 아래에(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbutton.cpp" line="709"/>
+        <location filename="../lxqttaskbutton.cpp" line="820"/>
         <source>&amp;Close</source>
         <translation>닫기(&amp;C)</translation>
     </message>
@@ -143,34 +153,34 @@
         <translation>창 그룹화(&amp;G)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="169"/>
         <source>Appearance</source>
         <translation>꾸미기</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="188"/>
         <source>Maximum button width</source>
         <translation>버튼 최대 폭</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
-        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="201"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="227"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="214"/>
         <source>Maximum button height</source>
         <translation>버튼 최대 높이</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
         <source>Auto&amp;rotate buttons when the panel is vertical</source>
         <translation>패널이 세로 일 때 버튼 자동 회전(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="247"/>
         <source>Use icons by WindowClass, if available</source>
         <translation>가능한 경우 WindowClass에 따른 아이콘 사용</translation>
     </message>
@@ -212,10 +222,15 @@
     <message>
         <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
         <source>Show popup on mouse hover</source>
-        <translation>마우스 호버 할 때 팝업 하기</translation>
+        <translation>마우스를 올릴 때 팝업 표시</translation>
     </message>
     <message>
-        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
+        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
+        <source>Put buttons of the same class next to each other</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.ui" line="178"/>
         <source>Button style</source>
         <translation>버튼 스타일</translation>
     </message>
@@ -242,15 +257,25 @@
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
         <source>Scroll up to raise, down to minimize</source>
-        <translation>아래로 스크롤하여 올리거나 내리고 최소화하십시오</translation>
+        <translation>스크롤을 올리면 최대화, 내리면 최소화</translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
         <source>Scroll up to minimize, down to raise</source>
-        <translation>최소화는 위로 스크롤,높이려면 아래로 스크롤</translation>
+        <translation>스크롤을 내리면 최소화, 올리면 최대화</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
+        <source>Scroll up to move to next desktop, down to previous</source>
+        <translation>스크롤을 올리면 다음 데스크톱으로, 내리면 이전 데스크톱으로 이동 </translation>
     </message>
     <message>
         <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
+        <source>Scroll up to move to previous desktop, down to next</source>
+        <translation>스크롤을 올리면 이전 데스크톱으로, 내리면 다음 데스크톱으로 이동</translation>
+    </message>
+    <message>
+        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
         <source>Current</source>
         <translation>현재</translation>
     </message>
