@@ -34,8 +34,11 @@
 #include <QDebug>
 #include <QTimer>
 #include <QX11Info>
+#include <algorithm>
+#include <vector>
 #include "trayicon.h"
 #include "../panel/ilxqtpanel.h"
+#include "../panel/pluginsettings.h"
 #include <LXQt/GridLayout>
 #include "lxqttray.h"
 #include "xfitman.h"
@@ -77,6 +80,7 @@ LXQtTray::LXQtTray(ILXQtPanelPlugin *plugin, QWidget *parent):
     mDisplay(QX11Info::display())
 {
     mLayout = new LXQt::GridLayout(this);
+    mLayout->setSpacing(mPlugin->settings()->value(QStringLiteral("spacing"), 0).toInt());
     realign();
     _NET_SYSTEM_TRAY_OPCODE = XfitMan::atom("_NET_SYSTEM_TRAY_OPCODE");
     // Init the selection later just to ensure that no signals are sent until
@@ -168,6 +172,16 @@ void LXQtTray::realign()
 }
 
 
+/************************************************
+
+ ************************************************/
+void LXQtTray::settingsChanged()
+{
+    mLayout->setSpacing(mPlugin->settings()->value(QStringLiteral("spacing"), 0).toInt());
+    sortIcons();
+}
+
+
 /************************************************
 
  ************************************************/
@@ -285,8 +299,8 @@ void LXQtTray::startTray()
     Display* dsp = mDisplay;
     Window root = QX11Info::appRootWindow();
 
-    QString s = QString("_NET_SYSTEM_TRAY_S%1").arg(DefaultScreen(dsp));
-    Atom _NET_SYSTEM_TRAY_S = XfitMan::atom(s.toLatin1());
+    QString s = QStringLiteral("_NET_SYSTEM_TRAY_S%1").arg(DefaultScreen(dsp));
+    Atom _NET_SYSTEM_TRAY_S = XfitMan::atom(s.toLatin1().constData());
 
     if (XGetSelectionOwner(dsp, _NET_SYSTEM_TRAY_S) != None)
     {
@@ -396,5 +410,32 @@ void LXQtTray::addIcon(Window winId)
     mIcons.append(icon);
     mLayout->addWidget(icon);
     connect(icon, &QObject::destroyed, this, &LXQtTray::onIconDestroyed);
+    sortIcons();
 }
 
+
+/************************************************
+
+ ************************************************/
+void LXQtTray::sortIcons()
+{
+    // there is currently no way to un-sort icons once sorted
+    if(!mPlugin->settings()->value(QStringLiteral("sortIcons"), false).toBool())
+        return;
+
+    std::vector<QLayoutItem *> items;
+
+    // temporarily remove all icons to sort them
+    for(QLayoutItem *item; (item = mLayout->takeAt(0)) != nullptr;)
+        items.push_back(item);
+
+    std::stable_sort(items.begin(), items.end(), [](QLayoutItem *a, QLayoutItem *b) {
+        auto ai = static_cast<TrayIcon *>(a->widget());
+        auto bi = static_cast<TrayIcon *>(b->widget());
+        return (ai->appName() < bi->appName());
+    });
+
+    // add them back in sorted order
+    for(QLayoutItem *item : items)
+        mLayout->addItem(item);
+}
