@@ -35,7 +35,7 @@
 
 AlsaEngine *AlsaEngine::m_instance = 0;
 
-static int alsa_elem_event_callback(snd_mixer_elem_t *elem, unsigned int mask)
+static int alsa_elem_event_callback(snd_mixer_elem_t *elem, unsigned int /*mask*/)
 {
     AlsaEngine *engine = AlsaEngine::instance();
     if (engine)
@@ -44,7 +44,7 @@ static int alsa_elem_event_callback(snd_mixer_elem_t *elem, unsigned int mask)
     return 0;
 }
 
-static int alsa_mixer_event_callback(snd_mixer_t *mixer, unsigned int mask, snd_mixer_elem_t *elem)
+static int alsa_mixer_event_callback(snd_mixer_t * /*mixer*/, unsigned int /*mask*/, snd_mixer_elem_t * /*elem*/)
 {
     return 0;
 }
@@ -165,10 +165,10 @@ void AlsaEngine::discoverDevices()
             qWarning("Can't get info for card %i: %s\n", cardNum, snd_strerror(error));
         } else {
             // setup mixer and iterate over channels
-            snd_mixer_t *mixer = 0;
+            snd_mixer_t *mixer = nullptr;
             snd_mixer_open(&mixer, 0);
             snd_mixer_attach(mixer, str);
-            snd_mixer_selem_register(mixer, NULL, NULL);
+            snd_mixer_selem_register(mixer, nullptr, nullptr);
             snd_mixer_load(mixer);
 
             // setup event handler for mixer
@@ -191,7 +191,7 @@ void AlsaEngine::discoverDevices()
                     AlsaDevice *dev = new AlsaDevice(Sink, this, this);
                     dev->setName(QString::fromLatin1(snd_mixer_selem_get_name(mixerElem)));
                     dev->setIndex(cardNum);
-                    dev->setDescription(cardName + " - " + dev->name());
+                    dev->setDescription(cardName + QStringLiteral(" - ") + dev->name());
 
                     // set alsa specific members
                     dev->setCardName(QString::fromLatin1(str));
