@@ -47,7 +47,7 @@
 OssEngine::OssEngine(QObject *parent) :
     AudioEngine(parent),
     m_mixer(-1),
-    m_device(NULL),
+    m_device(nullptr),
     m_leftVolume(0),
     m_rightVolume(0)
 {
@@ -70,9 +70,9 @@ void OssEngine::initMixer() {
     qDebug() << "InitMixer:" << m_mixer;
 
     m_device = new AudioDevice(Sink, this);
-    m_device->setName("Master");
+    m_device->setName(QStringLiteral("Master"));
     m_device->setIndex(0);
-    m_device->setDescription("Master Volume");
+    m_device->setDescription(QStringLiteral("Master Volume"));
     m_device->setMuteNoCommit(false);
     updateVolume();
 
@@ -113,7 +113,7 @@ void OssEngine::commitDeviceVolume(AudioDevice *device)
     setVolume(device->volume());
 }
 
-void OssEngine::setMute(AudioDevice *device, bool state)
+void OssEngine::setMute(AudioDevice * /*device*/, bool state)
 {
   if(state)
       setVolume(0);
@@ -121,7 +121,7 @@ void OssEngine::setMute(AudioDevice *device, bool state)
       setVolume(m_leftVolume);
 }
 
-void OssEngine::setIgnoreMaxVolume(bool ignore)
+void OssEngine::setIgnoreMaxVolume(bool /*ignore*/)
 {
   // TODO
 }
