@@ -38,14 +38,14 @@ static void sinkInfoCallback(pa_context *context, const pa_sink_info *info, int
 {
     PulseAudioEngine *pulseEngine = static_cast<PulseAudioEngine*>(userdata);
     QMap<pa_sink_state, QString> stateMap;
-    stateMap[PA_SINK_INVALID_STATE] = "n/a";
-    stateMap[PA_SINK_RUNNING] = "RUNNING";
-    stateMap[PA_SINK_IDLE] = "IDLE";
-    stateMap[PA_SINK_SUSPENDED] = "SUSPENDED";
+    stateMap[PA_SINK_INVALID_STATE] = QLatin1String("n/a");
+    stateMap[PA_SINK_RUNNING] = QLatin1String("RUNNING");
+    stateMap[PA_SINK_IDLE] = QLatin1String("IDLE");
+    stateMap[PA_SINK_SUSPENDED] = QLatin1String("SUSPENDED");
 
     if (isLast < 0) {
         pa_threaded_mainloop_signal(pulseEngine->mainloop(), 0);
-        qWarning() << QString("Failed to get sink information: %1").arg(pa_strerror(pa_context_errno(context)));
+        qWarning() << QStringLiteral("Failed to get sink information: %1").arg(QString::fromUtf8(pa_strerror(pa_context_errno(context))));
         return;
     }
 
@@ -57,7 +57,11 @@ static void sinkInfoCallback(pa_context *context, const pa_sink_info *info, int
     pulseEngine->addOrUpdateSink(info);
 }
 
-static void contextEventCallback(pa_context *context, const char *name, pa_proplist *p, void *userdata)
+static void contextEventCallback(pa_context * /*context*/, const char *
+#ifdef PULSEAUDIO_ENGINE_DEBUG
+        name
+#endif
+        , pa_proplist * /*p*/, void * /*userdata*/)
 {
 #ifdef PULSEAUDIO_ENGINE_DEBUG
     qWarning("event received %s", name);
@@ -113,7 +117,7 @@ static void contextSuccessCallback(pa_context *context, int success, void *userd
     pa_threaded_mainloop_signal(pulseEngine->mainloop(), 0);
 }
 
-static void contextSubscriptionCallback(pa_context *context, pa_subscription_event_type_t t, uint32_t idx, void *userdata)
+static void contextSubscriptionCallback(pa_context * /*context*/, pa_subscription_event_type_t t, uint32_t idx, void *userdata)
 {
     PulseAudioEngine *pulseEngine = reinterpret_cast<PulseAudioEngine*>(userdata);
     if (PA_SUBSCRIPTION_EVENT_REMOVE == t)
@@ -323,7 +327,7 @@ void PulseAudioEngine::connectContext()
         return;
     }
 
-    if (pa_context_connect(m_context, NULL, (pa_context_flags_t)0, NULL) < 0) {
+    if (pa_context_connect(m_context, nullptr, (pa_context_flags_t)0, nullptr) < 0) {
         pa_threaded_mainloop_unlock(m_mainLoop);
         m_reconnectionTimer.start();
         return;
@@ -347,7 +351,7 @@ void PulseAudioEngine::connectContext()
 
             case PA_CONTEXT_FAILED:
             default:
-                qWarning() << QString("Connection failure: %1").arg(pa_strerror(pa_context_errno(m_context)));
+                qWarning() << QStringLiteral("Connection failure: %1").arg(QString::fromUtf8(pa_strerror(pa_context_errno(m_context))));
                 keepGoing = false;
         }
 
