@@ -34,6 +34,7 @@
 #include <QDialog>
 #include <QLabel>
 
+
 #include <LXQt/RotatedWidget>
 
 #include "../panel/ilxqtpanelplugin.h"
@@ -61,6 +62,7 @@ public:
     virtual void settingsChanged();
     virtual void realign();
     QDialog *configureDialog();
+    bool eventFilter(QObject * watched, QEvent * event);
 
 private slots:
     void timeout();
@@ -84,6 +86,8 @@ private:
     QString mFormat;
 
     bool mAutoRotate;
+    bool mShowWeekNumber;
+    bool mShowTooltip;
     QLabel *mPopupContent;
 
     QDateTime mShownTime;
@@ -103,7 +107,7 @@ class ActiveLabel : public QLabel
 Q_OBJECT
 
 public:
-    explicit ActiveLabel(QWidget * = NULL);
+    explicit ActiveLabel(QWidget * = nullptr);
 
 signals:
     void wheelScrolled(int);
@@ -120,7 +124,7 @@ class LXQtWorldClockPopup : public QDialog
     Q_OBJECT
 
 public:
-    LXQtWorldClockPopup(QWidget *parent = 0);
+    LXQtWorldClockPopup(QWidget *parent = nullptr);
 
     void show();
 
