@@ -34,6 +34,8 @@
 #include "lxqtworldclockconfigurationtimezones.h"
 #include "lxqtworldclockconfigurationmanualformat.h"
 
+#include <LXQt/Globals>
+
 #include <QInputDialog>
 
 
@@ -82,6 +84,8 @@ LXQtWorldClockConfiguration::LXQtWorldClockConfiguration(PluginSettings *setting
     connect(ui->moveDownPB, SIGNAL(clicked()), SLOT(moveTimeZoneDown()));
 
     connect(ui->autorotateCB, SIGNAL(clicked()), SLOT(saveSettings()));
+    connect(ui->showWeekNumberCB, &QCheckBox::clicked, this, &LXQtWorldClockConfiguration::saveSettings);
+    connect(ui->showTooltipCB, SIGNAL(clicked()), SLOT(saveSettings()));
 
     loadSettings();
 }
@@ -138,6 +142,7 @@ void LXQtWorldClockConfiguration::loadSettings()
     ui->timeShowSecondsCB->setChecked(settings().value(QLatin1String("timeShowSeconds"), false).toBool());
     ui->timePadHourCB->setChecked(settings().value(QLatin1String("timePadHour"), false).toBool());
     ui->timeAMPMCB->setChecked(settings().value(QLatin1String("timeAMPM"), false).toBool());
+    ui->showTooltipCB->setChecked(settings().value(QLatin1String("showTooltip"), false).toBool());
 
     bool customTimeFormatSelected = ui->timeFormatCB->currentIndex() == ui->timeFormatCB->count() - 1;
     ui->timeCustomW->setEnabled(customTimeFormatSelected);
@@ -204,11 +209,11 @@ void LXQtWorldClockConfiguration::loadSettings()
     ui->advancedManualGB->setChecked(advancedManual);
 
 
-    mDefaultTimeZone = settings().value("defaultTimeZone", QString()).toString();
+    mDefaultTimeZone = settings().value(QStringLiteral("defaultTimeZone"), QString()).toString();
 
     ui->timeZonesTW->setRowCount(0);
 
-    QList<QMap<QString, QVariant> > list = settings().readArray(QLatin1String("timeZones"));
+    const QList<QMap<QString, QVariant> > list = settings().readArray(QLatin1String("timeZones"));
     int i = 0;
     for (const auto &map : list)
     {
@@ -229,8 +234,8 @@ void LXQtWorldClockConfiguration::loadSettings()
     ui->timeZonesTW->resizeColumnsToContents();
 
 
-    ui->autorotateCB->setChecked(settings().value("autoRotate", true).toBool());
-
+    ui->autorotateCB->setChecked(settings().value(QStringLiteral("autoRotate"), true).toBool());
+    ui->showWeekNumberCB->setChecked(settings().value(QL1S("showWeekNumber"), true).toBool());
 
     mLockCascadeSettingChanges = false;
 }
@@ -375,6 +380,8 @@ void LXQtWorldClockConfiguration::saveSettings()
     settings().setValue(QLatin1String("defaultTimeZone"), mDefaultTimeZone);
     settings().setValue(QLatin1String("useAdvancedManualFormat"), ui->advancedManualGB->isChecked());
     settings().setValue(QLatin1String("autoRotate"), ui->autorotateCB->isChecked());
+    settings().setValue(QL1S("showWeekNumber"), ui->showWeekNumberCB->isChecked());
+    settings().setValue(QLatin1String("showTooltip"), ui->showTooltipCB->isChecked());
 }
 
 void LXQtWorldClockConfiguration::timeFormatChanged(int index)
