@@ -4,7 +4,7 @@
 <context>
     <name>LXQtWorldClock</name>
     <message>
-        <location filename="../lxqtworldclock.cpp" line="244"/>
+        <location filename="../lxqtworldclock.cpp" line="246"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt; &lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
@@ -123,7 +123,7 @@
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
         <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="584"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="586"/>
         <source>Custom name</source>
         <translation>Nom personnalisé</translation>
     </message>
@@ -229,16 +229,21 @@
     </message>
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
-        <source>Show &amp;week number</source>
-        <translation>Afficher &amp;jour de la semaine</translation>
+        <source>Show &amp;week numbers in popup calendar</source>
+        <translation type="unfinished">Afficher les numéros de &amp;semaine dans le calendrier contextuel</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="106"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
+        <source>S&amp;how tooltip</source>
+        <translation type="unfinished">Montrer les infobulles</translation>
+    </message>
+    <message>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="107"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt; &lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="583"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
         <source>Input custom time zone name</source>
         <translation>Entrez le nom du fuseau horaire personnalisé</translation>
     </message>
@@ -276,8 +281,6 @@
 &lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;the milliseconds without leading zeroes (0 to 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;the milliseconds with leading zeroes (000 to 999)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
@@ -289,42 +292,40 @@
 &lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
 &lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
 </source>
-        <translation>&lt;h1&gt;Syntaxe du format de date/heure personnalisé&lt;/h1&gt;
-&lt;p&gt;Un modèle de date est une chaîne de caractères, des chaînes spécifiques étant remplacées par les données de date et d&apos;heure d&apos;un calendrier lors du formatage ou utilisées pour générer des données pour un calendrier lors de l&apos;analyse.&lt;/p&gt;
-&lt;p&gt;La table des symboles de champ de date ci-dessous contient les caractères utilisés dans les modèles pour afficher les formats appropriés pour un environnement local donné, tel que yyyy pour l&apos;année. Les caractères peuvent être utilisés plusieurs fois. Par exemple, si y est utilisé pour l&apos;année, &quot;yy&quot; peut produire &quot;99&quot;, alors que &quot;yyyy&quot; produit &quot;1999&quot;. Pour la plupart des champs numériques, le nombre de caractères spécifie la largeur du champ. Par exemple, si h est l&apos;heure, &quot;h&quot; peut produire &quot;5&quot;, mais &quot;hh&quot; produit &quot;05&quot;. Pour certains caractères, le nombre indique si une forme abrégée ou complète doit être utilisée, mais peut avoir d&apos;autres choix, comme indiqué ci-dessous.&lt;/P&gt;
-&lt;p&gt;Deux citations simples représentent une citation unique littérale, à l&apos;intérieur ou à l&apos;extérieur de citations simples. Le texte entre guillemets simples n&apos;est interprété d&apos;aucune façon (à l&apos;exception de deux guillemets simples adjacents). Sinon, toutes les lettres ASCII de a à z et de A à Z sont réservées en tant que caractères de syntaxe et nécessitent une citation si elles doivent représenter des caractères littéraux. De plus, certains caractères de ponctuation ASCII risquent de devenir variables à l&apos;avenir (par exemple, &quot;:&quot; étant interprété comme séparateur d&apos;heure et &apos;/&apos; comme séparateur de date, et remplacé par des caractères respectifs respectant les paramètres régionaux).&lt;br/&gt;&lt;/p&gt;
+        <translation type="unfinished">&lt;h1&gt;Syntaxe du format de date/heure personnalisé&lt;/h1&gt;
+&lt;p&gt;Un modèle de date est une chaîne de caractères, dans laquelle des chaînes de caractères spécifiques sont remplacées par des données de date et d&apos;heure d&apos;un calendrier lors du formatage ou utilisées pour générer des données pour un calendrier lors de l&apos;analyse.&lt;/p&gt;
+&lt;p&gt;Le tableau des symboles de champ de date ci-dessous contient les caractères utilisés dans les modèles pour afficher les formats appropriés pour un paramètre régional donné, tel que yyyy pour l&apos;année. Les caractères peuvent être utilisés plusieurs fois. Par exemple, si y est utilisé pour l&apos;année, «yy» peut produire «99», tandis que «yyyy» produit «1999». Pour la plupart des champs numériques, le nombre de caractères spécifie la largeur du champ. Par exemple, si h est l&apos;heure, «h» peut produire «5», mais «hh» produit «05». Pour certains caractères, le décompte spécifie si une forme abrégée ou complète doit être utilisée, mais il peut y avoir d&apos;autres choix, comme indiqué ci-dessous.&lt;/p&gt;
+&lt;p&gt;Deux guillemets simples représentent un guillemet simple littéral, à l&apos;intérieur ou à l&apos;extérieur des guillemets simples. Le texte entre guillemets simples n&apos;est en aucun cas interprété (à l&apos;exception de deux guillemets simples adjacents). Sinon, toutes les lettres ASCII de a à z et de A à Z sont réservées en tant que caractères de syntaxe et nécessitent des guillemets si elles doivent représenter des caractères littéraux. De plus, certains caractères de ponctuation ASCII peuvent devenir variables à l&apos;avenir (par ex, &quot;:&quot; étant interprété comme le séparateur d&apos;heure et &quot;/&quot; comme un séparateur de date, et remplacé par des caractères sensibles aux paramètres régionaux respectifs affichés).&lt;br /&gt;&lt;/p&gt;
 &lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
-&lt;tr&gt; th width = &quot;20%&quot;&gt; Code &lt;/ th&gt; &lt;th&gt; Signification &lt;/ th&gt; &lt;/ tr&gt;
-&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;le jour en tant que nombre sans zéro (1 à 31)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;le jour sous forme de nombre avec un zéro (01 à 31) &lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;nom abrégé du jour localisé (par exemple, &quot;Mon&quot; à &quot;Soleil&quot;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;le nom de jour long localisé (par exemple, &quot;lundi&quot; à &quot;dimanche&quot;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;le mois sous la forme d&apos;un nombre sans zéro (1-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;le mois sous la forme d&apos;un nombre avec un zéro (01-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;nom abrégé du mois localisé (par exemple, &quot;Jan&quot; à &quot;Déc&quot;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;nom de mois long localisé (par exemple, &quot;janvier&quot; à &quot;décembre&quot;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;l&apos;année sous forme de numéro à deux chiffres (00-99)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;aaaa&lt;/td&gt;&lt;td&gt;l&apos;année sous forme de numéro à quatre chiffres&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;h&lt;/ td&gt;&lt;td&gt;l&apos;heure sans zéro (0 à 23 ou 1 à 12 si affichage AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;l&apos;heure précédée d&apos;un zéro (00 à 23 ou 01 à 12 si affichage AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt; H &lt;/ td&gt;&lt;td&gt;l&apos;heure sans zéro (0 à 23, même avec l&apos;affichage AM / PM) &lt;/ td&gt; &lt;/ tr&gt;
-&lt;tr&gt;&lt;td&gt; HH &lt;/ td&gt;&lt;td&gt;l&apos;heure avec un zéro non significatif (00 à 23, même avec l&apos;affichage AM/PM) &lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;la minute sans zéro (0 à 59)&lt;/td&gt;&lt;/ tr&gt;
-&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;la minute précédée d&apos;un zéro (00 à 59)&lt;/td&gt;&lt;/ tr&gt;
-&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;la seconde sans zéro (0 à 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;le deuxième avec un zéro non significatif (00 à 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;les millisecondes sans zéros au début (0 à 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;les millisecondes avec des zéros non significatifs (000 à 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;AP&lt;i&gt;ou&lt;/i&gt;A&lt;/td&gt;&lt;td&gt;utilise l&apos;affichage AM/PM.&lt;b&gt;A/AP&lt;/b&gt;sera remplacé par &quot;AM&quot; ou &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ap&lt;i&gt;ou&lt;/i&gt;a&lt;/td&gt;&lt;td&gt;utilise l&apos;affichage am/pm.&lt;b&gt;a/ap&lt;/b&gt;sera remplacé par &quot;am&quot; ou &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;t&lt;/ td&gt;&lt;td&gt;le fuseau horaire (par exemple, &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Signification&lt;/th&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;le jour sous forme de nombre sans zéro non significatif (1 à 31)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;le jour sous forme de nombre avec un zéro non significatif (01 à 31)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;le nom abrégé du jour localisé (ex, &apos;Lun&apos; à &apos;Dim&apos;).&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;le nom complet du jour localisé (ex, &apos;Lundi&apos; à &apos;Dimanche&apos;).&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;le mois sous forme de nombre sans zéro non significatif (1-12)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;le mois sous forme de nombre avec zéro non significatif (01-12)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;le nom abrégé du mois localisé (ex, &apos;Jan&apos; à &apos;Déc&apos;).&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;le nom complet du mois localisé ( &apos;Janvier&apos; à &apos;Décembre&apos;).&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;l&apos;année sous forme de nombre à deux chiffres (00-99)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;l&apos;année sous forme de nombre à quatre chiffres&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;l&apos;heure sans zéro non significatif (0 à 23 ou 1 à 12 si affichage AM/PM)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;l&apos;heure avec zéro non significatif (00 à 23 ou 01 à 12 si affichage AM/PM)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;l&apos;heure sans zéro non significatif (0 à 23, même si affichage AM/ PM)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;l&apos;heure avec un zéro non significatif (00 à 23, même si affichage AM/PM)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;la minute sans zéro non significatif (0 à 59)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;la minute avec un zéro non significatif (00 à 59)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;la seconde sans zéro non significatif (0 à 59)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;le second avec un zéro non significatif (00 à 59)&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;ou&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;utiliser l&apos;affichage AM / PM. &lt;b&gt;A/AP&lt;/b&gt; sera remplacé par &quot;AM&quot; ou &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;ou&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;utiliser l&apos;affichage am/pm &lt;b&gt;a/ap&lt;/b&gt; sera remplacé par &quot;am&quot; ou &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;le fuseau horaire (par exemple &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;le décalage par rapport à UTC&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;l&apos;identifiant IANA du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;l&apos;abréviation du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;nom d&apos;affichage abrégé du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;nom d&apos;affichage complet du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;le nom personnalisé du fuseau horaire. Vous pouvez modifier l&apos;onglet &quot;Fuseaux horaires&quot; de la fenêtre de configuration&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
-&lt;br/&gt;&lt;b&gt;Remarques:&lt;/b&gt;&lt;ul&gt;&lt;li&gt;Tous les caractères du modèle qui ne figurent pas dans les plages de [&apos;a&apos; .. &apos;z&apos;] et de &apos;&apos; A &apos;..&apos; Z &apos;] sera traité comme un texte cité. Par exemple, des caractères tels que &apos;:&apos;, &apos;.&apos;, &apos;&apos;, &apos;#&apos; Et &apos;@&apos; apparaîtront dans le texte temporel résultant, même s&apos;ils ne sont pas entourés de guillemets simples. La citation simple est utilisée pour &quot;échapper&quot; aux lettres. Deux guillemets simples à la suite, que ce soit à l&apos;intérieur ou à l&apos;extérieur d&apos;une séquence citée, représentent un guillemet simple &quot;réel&quot;.&lt;/Li&gt;&lt;li&gt;L&apos;intervalle de mise à jour minimal est de 1 seconde. Si z ou zzz est configuré, l&apos;heure est indiquée avec la fraction en millisecondes, mais n&apos;est pas mise à jour sur une base milliseconde (évitant ainsi de nuire aux performances).&lt;/Li&gt;&lt;ul&gt;
+&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;l&apos;abréviation du fuseau horraire&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;le nom d&apos;affichage court du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;le nom d&apos;affichage long du fuseau horaire&lt;/td&gt;&lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;le nom personnalisé du fuseau horaire. Modifiable dans l&apos;onglet &apos;Fuseaux horaires&apos; de la fenêtre de configuration&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
+&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Tous les caractères du motif qui ne sont pas dans les plages [&apos;a&apos; .. &apos;z&apos;] et [&apos;A&apos; .. &apos;Z&apos;] seront traités comme du texte entre guillemets. Par exemple, des caractères comme «:», «.», «,», «#» Et «@» apparaîtront dans le texte temporel résultant même s&apos;ils ne sont pas entourés de guillemets simples. Le guillemet simple est utilisé pour «échapper» les lettres. Deux guillemets simples dans une ligne, que ce soit à l&apos;intérieur ou à l&apos;extérieur d&apos;une séquence entre guillemets, représentent un guillemet simple «réel». &lt;/li&gt;&lt;li&gt; L&apos;intervalle de mise à jour minimal est de 1 seconde. Si z ou zzz est configuré, le temps est affiché avec la fraction de millisecondes, mais il n&apos;est pas mis à jour sur une base de millisecondes (évitant de gros problèmes de performances).&lt;/li&gt;&lt;ul&gt;
 </translation>
     </message>
 </context>
