@@ -4,7 +4,7 @@
 <context>
     <name>LXQtWorldClock</name>
     <message>
-        <location filename="../lxqtworldclock.cpp" line="244"/>
+        <location filename="../lxqtworldclock.cpp" line="246"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;UU:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM jjjj&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
@@ -14,7 +14,7 @@
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
         <source>World Clock Settings</source>
-        <translation>Instellingen van Wereldklok</translation>
+        <translation>Instellingen van Klok</translation>
     </message>
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
@@ -123,7 +123,7 @@
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
         <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="584"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="586"/>
         <source>Custom name</source>
         <translation>Aangepaste naam</translation>
     </message>
@@ -229,16 +229,21 @@
     </message>
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
-        <source>Show &amp;week number</source>
-        <translation>Toon &amp;weeknummer</translation>
+        <source>Show &amp;week numbers in popup calendar</source>
+        <translation>Toon &amp;weeknummers in popupkalender</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="106"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
+        <source>S&amp;how tooltip</source>
+        <translation>Toon &amp;tooltip</translation>
+    </message>
+    <message>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="107"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;UU:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM jjjj&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="583"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
         <source>Input custom time zone name</source>
         <translation>Geef aangepaste naam in voor tijdzone</translation>
     </message>
@@ -248,7 +253,7 @@
     <message>
         <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
         <source>World Clock Manual Format Configuration</source>
-        <translation>Handmatig instellen wereldklokformaat</translation>
+        <translation>Handmatig instellen klokweergave</translation>
     </message>
     <message>
         <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
@@ -276,8 +281,6 @@
 &lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;the milliseconds without leading zeroes (0 to 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;the milliseconds with leading zeroes (000 to 999)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
@@ -289,44 +292,7 @@
 &lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
 &lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
 </source>
-        <translation>&lt;h1&gt;Syntax van aangepaste datum/tijd-opmaak&lt;/h1&gt;
-&lt;p&gt;Een datumpatroon is een tekenreeks, waarvan specifieke tekens worden vervangen door datum- en tijdgegevens van een kalender bij het opmaken of waarvan die worden gebruikt om gegevens aan te maken voor een kalender bij het inlezen.&lt;/p&gt;
-&lt;p&gt;De datumveld-symbooltabel hieronder bevat de tekens die worden gebruikt in patronen om de juiste opmaak te tonen voor een opgegeven regionale instelling, zoals &apos;jjjj&apos; voor het jaar. Tekens kunnen meerdere malen worden gebruikt. Bijvoorbeeld: als &apos;j&apos; wordt gebruikt voor het jaar, dan zou &apos;jj&apos; &apos;18&apos; kunnen voortbrengen, terwijl &apos;jjjj&apos; &apos;2018&apos; voortbrengt. Voor de meeste numerieke velden bepaalt het aantal tekens de veldbreedte. Bijvoorbeeld: als &apos;u&apos; het uur is, dan zou het &apos;5&apos; kunnen voortbrengen, maar &apos;uu&apos; brengt &apos;05&apos; voort. Voor sommige tekens bepaalt het aantal of er een afgekorte dan wel een volledige vorm wordt gebruikt, maar er kunnen ook andere keuzes zijn, zoals onderstaand aangegeven.&lt;/p&gt;
-&lt;p&gt;Twee enkele aanhalingstekens representeren een letterlijk enkel aanhalingsteken, hetzij binnen enkele aanhalingstekens hetzij daarbuiten. Tekst binnen enkele aanhalingstekens wordt op geen enkele wijze geïnterpreteerd (behalve twee opeenvolgende enkele aanhalingstekens). Voor de rest worden alle ASCII-letters van a tot en met z en van A tot en met Z gereserveerd als syntax-tekens, waardoor zij tussen aanhalingstekens moeten worden gezet indien zij letterlijke tekens moeten voorstellen. Bovendien zouden bepaalde ASCII-interpunctietekens in de toekomst variabel kunnen worden (bijvoorbeeld &apos;:&apos; geïnterpreteerd als tijdscheidingsteken en &apos;/&apos; als datumscheidingsteken, en worden vervangen door hun respectievelijke regio-afhankelijke tekens op het scherm).&lt;br /&gt;&lt;/p&gt;
-&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
-&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Betekenis&lt;/th&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;de dag als getal zonder een inleidende nul (1 tot en met 31)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;de dag als getal met een inleidende nul (01 tot en met 31)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;de afgekorte regionale dagnaam (bijvoorbeeld &apos;ma&apos; tot en met &apos;zo&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;de lange regionale dagnaam (bijvoorbeeld &apos;maandag&apos; tot en met &apos;zondag&apos;)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;de maand als getal zonder een inleidende nul (1-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;de maand als getal met een inleidende nul (01-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;de afgekorte regionale maandnaam (bijvoorbeeld: &apos;jan&apos; tot en met &apos;dec&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;de lange regionale maandnaam (bijvoorbeeld: &apos;januari&apos; tot en met &apos;december&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;jj&lt;/td&gt;&lt;td&gt;het jaar als tweecijferig getal (00-99)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;jjjj&lt;/td&gt;&lt;td&gt;het jaar als viercijferig getal&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;u&lt;/td&gt;&lt;td&gt;het uur zonder een inleidende nul (0 tot en met 23 of 1 tot en met 12 indien vm/nm-aanduiding)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;uu&lt;/td&gt;&lt;td&gt;het uur met een inleidende nul (00 tot en met 23 of 01 tot en met 12 indien vm/nm-aanduiding)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;U&lt;/td&gt;&lt;td&gt;het uur zonder een inleidende nul (0 tot en met 23, zelfs met vm/nm-aanduiding)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;UU&lt;/td&gt;&lt;td&gt;het uur met een inleidende nul (00 tot en met 23, zelfs met vm/nm-aanduiding)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;de minuut zonder een inleidende nul (0 tot en met 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;de minuut met een inleidende nul (00 tot en met 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;de seconde zonder een inleidende nul (0 tot en met 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;de seconde met een inleidende nul (00 tot en met 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;de milliseconde zonder inleidende nullen (0 tot en met 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;de milliseconde met inleidende nullen (000 tot en met 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;of&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;gebruik VM/NM-aanduiding. &lt;b&gt;A/AP&lt;/b&gt; zal worden vervangen door &quot;VM&quot; of &quot;NM&quot;.&lt;&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;of&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;gebruik vm/nm-aanduiding. &lt;b&gt;a/ap&lt;/b&gt; zal worden vervangen door &quot;vm&quot; of &quot;nm&quot;.&lt;&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;de tijdzone (bijvoorbeeld &apos;CEST&apos;)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;het verschil met UTC&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;het IANA-id van de tijdzone&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;de afkorting van de tijdzone&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;de korte naamweergave van de tijdzone&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;de lange naamweergave van de tijdzone&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;de aangepaste naam van de tijdzone. U kunt die wijzigen in het tabblad &apos;Tijdzones&apos; van het instellingenvenster&lt;/td&gt;&lt;/tr&gt;
-&lt;/table&gt;
-&lt;br /&gt;&lt;b&gt;Let op:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;alle tekens in het patroon die niet vallen in het bereik van [&apos;a&apos;..&apos;z&apos;] en [&apos;A&apos;..&apos;Z&apos;] zullen worden behandeld als tekst tussen aanhalingstekens. Bijvoorbeeld: tekens als &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; en &apos;@&apos; zullen verschijnen in de resulterende tijdtekst, zelfs als ze niet tussen enkele aanhalingstekens zijn geplaatst. Het enkele aanhalingsteken wordt gebruikt om letters &apos;af te zonderen&apos;. Twee enkele aanhalingstekens achter elkaar, hetzij binnen een geciteerde zin hetzij daarbuiten, stellen een &apos;echt&apos; enkel aanhalingsteken voor.&lt;/li&gt;&lt;li&gt;De minimale tussenpoze voor bijwerken is 1 seconde. Indien z of zzz is ingesteld, wordt de tijd getoond met de milliseconden erbij, maar de tijd wordt niet per milliseconde bijgewerkt (om zo een enorme systeembelasting te vermijden!).&lt;/li&gt;&lt;ul&gt;
-</translation>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -334,7 +300,7 @@
     <message>
         <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
         <source>World Clock Time Zones</source>
-        <translation>Tijdzones van Wereldklok</translation>
+        <translation>Tijdzones van Klok</translation>
     </message>
     <message>
         <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
