@@ -4,7 +4,7 @@
 <context>
     <name>LXQtWorldClock</name>
     <message>
-        <location filename="../lxqtworldclock.cpp" line="244"/>
+        <location filename="../lxqtworldclock.cpp" line="246"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d &apos;de&apos; MMM &apos;de&apos; yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
@@ -118,7 +118,7 @@
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
         <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="584"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="586"/>
         <source>Custom name</source>
         <translation>Nome personalizado</translation>
     </message>
@@ -229,16 +229,21 @@
     </message>
     <message>
         <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
-        <source>Show &amp;week number</source>
-        <translation>Exibir número da &amp;semana</translation>
+        <source>Show &amp;week numbers in popup calendar</source>
+        <translation>Exibir os números da &amp;semana no calendário pop-up</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="106"/>
+        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
+        <source>S&amp;how tooltip</source>
+        <translation>E&amp;xibir dicas</translation>
+    </message>
+    <message>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="107"/>
         <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
         <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br /&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br /&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
     </message>
     <message>
-        <location filename="../lxqtworldclockconfiguration.cpp" line="583"/>
+        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
         <source>Input custom time zone name</source>
         <translation>Inserir nome do fuso horário personalizado</translation>
     </message>
@@ -276,8 +281,6 @@
 &lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;the milliseconds without leading zeroes (0 to 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;the milliseconds with leading zeroes (000 to 999)&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
 &lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
@@ -289,42 +292,40 @@
 &lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
 &lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
 </source>
-        <translation>&lt;h1&gt;Formato Personalizado de Data/Hora &lt;/h1&gt;
-&lt;p&gt;Um padrão de data é uma sequência de caracteres, em que a sequência de caracteres especificados são substituídos por dados de data e hora de um calendário ao formatar ou usados para gerar dados para um calendário durante a análise. &lt;/p&gt;
-&lt;p&gt;A Tabela de Símbolo de Campo de Data abaixo contém os caracteres usados nos padrões para mostrar os formatos apropriados para uma determinada localidade, como yyyy para o ano. Caracteres podem ser usados várias vezes. Por exemplo, se y for usado para o ano, &apos;yy&apos; produzirá &apos;99&apos;, enquanto &apos;yyyy&apos; produzirá &apos;1999&apos;. Para a maioria dos campos numéricos, o número de caracteres especifica a largura do campo. Por exemplo, se h é a hora, &apos;h&apos; produz &apos;5&apos;, mas &apos;hh&apos; produz &apos;05&apos;. Para alguns caracteres, a contagem especifica se um formulário completo ou abreviado deve ser usado, mas pode ter outras opções, conforme indicado abaixo. &lt;/p&gt;
-&lt;p&gt;Duas aspas simples representam uma aspa simples literal, dentro ou fora de aspas simples. O texto entre aspas simples não é interpretado de forma alguma (exceto por duas aspas simples adjacentes). Caso contrário, todas as letras ASCII de a para z e de A para Z são reservadas como caracteres de sintaxe e requerem aspas para representar caracteres literais. Além disso, determinados caracteres de pontuação ASCII podem se tornar variáveis no futuro (por exemplo, &quot;:&quot; sendo interpretado como o separador de hora e &quot;/&quot; como um separador de data, e substituído por respectivos caracteres sensíveis ao local na tela).&lt;br /&gt;&lt;/p&gt;
-&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
-&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Código&lt;/th&gt;&lt;th&gt;Significado&lt;/th&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;o dia como número sem zero à esquerda (1 à 31)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;o dia como número com zero à esquerda (01 à 31)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;o nome abreviado do dia localizado (ex. &apos;Seg&apos; à &apos;Dom&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;o nome longo do dia localizado (ex. &apos;Segunda&apos; à &apos;Domingo&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;o mês como número sem zero à esquerda (1-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;o mês como número com zero à esquerda (01-12)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;o nome abreviado do mês localizado (ex. &apos;Jan&apos; à &apos;Dez&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;o nome longo do mês localizado (ex. &apos;Janeiro&apos; à &apos;Dezembro&apos;).&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;o ano como número de dois dígitos (00-99)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;o ano como número de quatro dígitos&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;a hora sem zero à esquerda (0 a 23 ou 1 a 12, se exibir AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;a hora com zero à esquerda (00 a 23 ou 01 a 12 se exibir AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;a hora sem zero à esquerda (0 a 23, mesmo exibindo AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;a hora com zero à esquerda (00 a 23, mesmo exibindo AM/PM)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;o minuto sem zero à esquerda (0 a 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;o minuto com zero à esquerda (00 a 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;o segundo sem zero à esquerda (0 a 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;o segundo com zero à esquerda (00 a 59)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;z&lt;/td&gt;&lt;td&gt;os milissegundos sem zeros à esquerda (0 a 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;zzz&lt;/td&gt;&lt;td&gt;os milissegundos com zeros à esquerda (000 a 999)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;ou&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;exibe AM/PM. &lt;b&gt;A/AP&lt;/b&gt; será substituído por &quot;AM&quot; ou &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;ou&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;exibe am/pm. &lt;b&gt;a/ap&lt;/b&gt; será substituído por &quot;am&quot; ou &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;o fuso horário (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;o deslocamento de UTC&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;o id do fuso horário IANA&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;a abreviação do fuso horário&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;o nome curto do fuso horário&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;o nome longo do fuso horário&lt;/td&gt;&lt;/tr&gt;
-&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;o nome personalizado do fuso horário. Você pode alterar a guia &apos;Fusos horários&apos; da janela de configuração&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
-&lt;br /&gt;&lt;b&gt;Nota:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Quaisquer caracteres no padrão que não estejam nos intervalos de [&apos;a&apos; .. &apos;z&apos;] e [&apos;A&apos; .. &apos;Z&apos;] serão tratados como texto entre aspas. Por exemplo, caracteres como &apos;:&apos;, &apos;.&apos;, &apos;&apos;, &apos;#&apos; e &apos;@&apos; aparecerão no texto de tempo resultante, mesmo que não estejam entre aspas simples. A aspa simples é usada para &apos;escapar&apos; letras. Duas aspas simples em uma linha, dentro ou fora de uma sequência citada, representam uma aspa simples &apos;real&apos;. &lt;/li&gt;&lt;li&gt; O intervalo mínimo de atualização é de 1 segundo. Se z ou zzz forem configurados, o horário será mostrado com a fração de milissegundos, mas não será atualizado em milissegundos (evitando um grande impacto no desempenho).&lt;/li&gt;&lt;/ul&gt;
+        <translation>&lt;h1&gt; Sintaxe de formato de data / hora personalizado &lt;/h1&gt;
+&lt;p&gt; Um padrão de data é uma sequência de caracteres, em que sequências específicas de caracteres são substituídas por dados de data e hora de um calendário durante a formatação ou usados para gerar dados para um calendário durante a análise. &lt;/p&gt;
+&lt;p&gt; A Tabela de símbolos do campo de data abaixo contém os caracteres usados em padrões para mostrar os formatos apropriados para um determinado local, como aaaa para o ano. Os caracteres podem ser usados várias vezes. Por exemplo, se y for usado para o ano, &apos;yy&apos; pode produzir &apos;99&apos;, enquanto &apos;yyyy&apos; produz &apos;1999&apos;. Para a maioria dos campos numéricos, o número de caracteres especifica a largura do campo. Por exemplo, se h é a hora, &apos;h&apos; pode produzir &apos;5&apos;, mas &apos;hh&apos; produz &apos;05&apos;. Para alguns caracteres, a contagem especifica se uma forma abreviada ou completa deve ser usada, mas pode haver outras opções, conforme mostrado abaixo. &lt;/p&gt;
+&lt;p&gt; Duas aspas simples representam uma aspa simples literal, dentro ou fora das aspas simples. O texto entre aspas simples não é interpretado de forma alguma (exceto para duas aspas simples adjacentes). Caso contrário, todas as letras ASCII de a a z e de A a Z são reservadas como caracteres de sintaxe e requerem aspas para representar caracteres literais. Além disso, certos caracteres de pontuação ASCII podem se tornar variáveis no futuro (por exemplo, &quot;:&quot; sendo interpretado como o separador de hora e &apos;/&apos; como um separador de data, e substituído pelos respectivos caracteres sensíveis ao local no display). &lt;br /&gt; &lt; / p&gt;
+&lt;table border = &quot;1&quot; width = &quot;100%&quot; cellpadding = &quot;4&quot; cellspacing = &quot;0&quot;&gt;
+&lt;tr&gt; &lt;th width = &quot;20%&quot;&gt; Código &lt;/th&gt; &lt;th&gt; Significado &lt;/th&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;d&lt;/td&gt; &lt;td&gt; o dia como um número sem zero à esquerda (1 a 31) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt; &lt;td&gt; o dia como um número com um zero à esquerda (01 a 31) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt; &lt;td&gt; o nome abreviado do dia localizado (por exemplo, &apos;Seg&apos; para &apos;Sol&apos;). &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt; &lt;td&gt; o nome longo do dia localizado (por exemplo, &apos;Segunda-feira&apos; a &apos;Domingo&apos;). &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;M&lt;/td&gt; &lt;td&gt; o mês como um número sem zero à esquerda (1-12) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt; &lt;td&gt; o mês como um número com um zero à esquerda (01-12) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt; &lt;td&gt; o nome abreviado do mês localizado (por exemplo, &apos;Jan&apos; a &apos;Dez&apos;). &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt; &lt;td&gt; o nome longo do mês localizado (por exemplo, &apos;janeiro&apos; a &apos;dezembro&apos;). &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt; &lt;td&gt; o ano como um número de dois dígitos (00-99) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt; &lt;td&gt; o ano como um número de quatro dígitos &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;h&lt;/td&gt; &lt;td&gt; a hora sem zero à esquerda (0 a 23 ou 1 a 12 se exibir AM / PM) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt; &lt;td&gt; a hora com um zero à esquerda (00 a 23 ou 01 a 12 se exibir AM / PM) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;H&lt;/td&gt; &lt;td&gt; a hora sem zero à esquerda (0 a 23, mesmo com exibição de AM / PM) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt; &lt;td&gt; a hora com um zero à esquerda (00 a 23, mesmo com exibição de AM / PM) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;m&lt;/td&gt; &lt;td&gt; o minuto sem zero à esquerda (0 a 59) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt; &lt;td&gt; o minuto com um zero à esquerda (00 a 59) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;s&lt;/td&gt; &lt;td&gt; o segundo sem zero à esquerda (0 a 59) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt; &lt;td&gt; o segundo com um zero à esquerda (00 a 59) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt; &lt;td&gt; AP &lt;i&gt; ou &lt;/i&gt; A &lt;/td&gt; &lt;td&gt; usa exibição AM / PM. &lt;b&gt; A / AP &lt;/b&gt; será substituído por &quot;AM&quot; ou &quot;PM&quot;. &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt; &lt;td&gt; ap &lt;i&gt; ou &lt;/i&gt; a &lt;/td&gt; &lt;td&gt; use a exibição am / pm. &lt;b&gt; a / ap &lt;/b&gt; será substituído por &quot;am&quot; ou &quot;pm&quot;. &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;t&lt;/td&gt; &lt;td&gt; o fuso horário (por exemplo, &quot;CEST&quot;) &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;T&lt;/td&gt; &lt;td&gt; o deslocamento do UTC &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt; &lt;td&gt; o ID do fuso horário IANA &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt; &lt;td&gt; a abreviação do fuso horário &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt; &lt;td&gt; o nome de exibição abreviado do fuso horário &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt; &lt;td&gt; o nome de exibição longo do fuso horário &lt;/td&gt; &lt;/tr&gt;
+&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt; &lt;td&gt; o nome personalizado do fuso horário. Você pode alterá-lo na guia &apos;Fusos horários&apos; da janela de configuração &lt;/td&gt; &lt;/tr&gt; &lt;/table&gt;
+&lt;br /&gt; &lt;b&gt; Observações: &lt;/b&gt; &lt;ul&gt; &lt;li&gt; Quaisquer caracteres no padrão que não estejam nos intervalos de [&apos;a&apos; .. &apos;z&apos;] e [&apos;A&apos; .. &apos;Z &apos;] será tratado como texto citado. Por exemplo, caracteres como &apos;:&apos;, &apos;.&apos;, &apos;&apos;, &apos;#&apos; E &apos;@&apos; aparecerão no texto da hora resultante, mesmo que não estejam entre aspas simples. A aspa simples é usada para &apos;escapar&apos; letras. Duas aspas simples consecutivas, seja dentro ou fora de uma sequência entre aspas, representam uma aspa simples &apos;real&apos;. &lt;/li&gt; &lt;li&gt; O intervalo mínimo de atualização é de 1 segundo. Se z ou zzz for configurado, o tempo é mostrado com a fração de milissegundos, mas não atualizado em uma base de milissegundos (evitando grande impacto no desempenho). &lt;/li&gt; &lt;ul&gt;
 </translation>
     </message>
 </context>
